@@ -33,10 +33,10 @@ class Pesepay:
 
     def initiate_transaction(self, transaction: Transaction):
         if self.result_url is None:
-            raise 'Result url has not been specified'
+            raise InvalidRequestException('Result url has not been specified')
 
         if self.return_url is None:
-            raise 'Return url has not been specified'
+            raise InvalidRequestException('Return url has not been specified')
 
         transaction.resultUrl = self.result_url
         transaction.returnUrl = self.return_url
@@ -77,7 +77,7 @@ class Pesepay:
     def make_seamless_payment(self, payment: Payment, reason_for_payment: string, amount: float,
                               required_fields: dict = None):
         if self.result_url is None:
-            raise 'Result url has not been specified'
+            raise InvalidRequestException('Result url has not been specified')
 
         payment.resultUrl = self.result_url
         payment.returnUrl = self.return_url
@@ -143,4 +143,4 @@ class Pesepay:
 
 class InvalidRequestException(Exception):
     def __init__(self, message):
-        super(InvalidRequestException, self).__init__(message)
+        super().__init__(message)
